OC.L10N.register(
    "forms",
    {
    "No" : "නැහැ",
    "Copy" : "පිටපත්",
    "Anonymous response" : "නිර්නාමික ප්‍රතිචාරය",
    "responses" : "ප්‍රතිචාර",
    "Cancel" : "අවලංගු",
    "Other" : "වෙනත්",
    "Group" : "සමූහය",
    "Edit" : "සංස්කරණය",
    "Share" : "බෙදාගන්න",
    "Description" : "විස්තරය",
    "Summary" : "සාරාංශය",
    "Responses" : "ප්‍රතිචාර",
    "Download" : "බාගන්න",
    "Search" : "සොයන්න",
    "Settings" : "සැකසුම්",
    "Abort" : "රෝධනය",
    "File" : "ගොනුව",
    "Date" : "දිනය",
    "Time" : "වේලාව",
    "Phone number" : "දුරකථන අංකය",
    "Uploading …" : "උඩුගත වෙමින්…"
},
"nplurals=2; plural=(n != 1);");
